.. _installing:

Installation
============

Required dependencies
---------------------

- Python 3.5 or later
- `dask <https://dask.org>`__
- `numba <http://numba.pydata.org>`__
- `numpy <http://www.numpy.org>`__
- `scipy <https://www.scipy.org>`__

Testing
-------

To run the test suite after installing pyscenarios, first install
(via pypi or conda)

- `py.test <https://pytest.org>`__: Simple unit testing library

and run
``py.test``.

